@@ -1,12 +1,8 @@
 # -*- coding: utf-8 -*-
-"""
-Iterable ZIP archive generator.
 
-Derived directly from zipfile.py
-"""
 from __future__ import unicode_literals, print_function, with_statement
 
-__version__ = '1.2.2'
+__version__ = '3.0.1'
 __author__ = 'Santiago Debus - Grow HQ, Inc.'
 __license__ = 'MIT'
 
