@@ -78,7 +78,7 @@ class ZipFly:
         self.comment = b'Written using Buzon-ZipFly'
         self.mode = mode
         self.paths = paths
-        self.chunksize = chunksize
+        self.chunksize = int(chunksize)
         self.compression = compression
         self.allowZip64 = allowZip64
         self.compresslevel = compresslevel
@@ -118,17 +118,9 @@ class ZipFly:
 
     def buffer_prediction_size(self):
 
-        """
-        we need the sum in of all characteres in a filename in the zip
-        example: 
-            1) 'a' has 1 byte in utf-8 format ( b'a' )
-            2) 'ñ' has 2 bytes in utf'8 format ( b'\xc3\xb1' )
-            3) '传' has 3 bytes in utf-8 format ( b'\xe4\xbc\xa0' )
-        """        
-
         # initial values
         _len = len( self.paths )
-        _len_utf8 = int( 0x2 ) * _len
+        _len_utf8 = int( 0x2 ) * _len  # magic number
 
         # Empty zip size in bytes
         # zip initial size for multiple files
@@ -140,7 +132,6 @@ class ZipFly:
             paths = self.paths,
             ss = self.storesize,
         )
-        b.paths_size_in_bytes()
 
         # zip size in bytes
         return int(
@@ -163,11 +154,12 @@ class ZipFly:
 
         stream = Stream()
         
+
+
         with ZipFile(stream,
                      mode = self.mode,
                      compression = self.compression,
-                     allowZip64 = self.allowZip64,
-                     compresslevel = self.compresslevel) as zf:
+                     allowZip64 = self.allowZip64,) as zf:
 
             for path in self.paths:             
 
